<?php

namespace June\Controller\Api;

use Exception;
use June\Service\ScheduledTask\ExportNewsletterSubscriberTask;
use June\Service\ScheduledTask\ExportOrdersTask;
use Shopware\Core\Framework\Routing\Annotation\RouteScope;
use Shopware\Core\System\SystemConfig\SystemConfigService;
use Symfony\Bundle\FrameworkBundle\Console\Application;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Console\Input\ArrayInput;
use Symfony\Component\Console\Output\BufferedOutput;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\KernelInterface;
use Symfony\Component\Routing\Annotation\Route;

/**
 * Class ExportController
 * @package June\Controller\StoreApi
 */
#[Route(defaults: ['_routeScope' => ['api']])]
class ExportController extends AbstractController {
    private SystemConfigService $configService;

    private KernelInterface $kernel;

    public function __construct
    (
        SystemConfigService $configService,
        KernelInterface $kernel
    )
    {
        $this->configService = $configService;
        $this->kernel = $kernel;
    }

    /**
     * @throws Exception
     */
    #[Route('/api/june-export-orders', name: 'api.extension.export_orders', defaults: ['auth_required'=>false], methods: ['GET'])]
    function startOrderExport(): Response {
        $this->configService->set('June.config.orderOffset', 0);
        $this->configService->set('June.config.startExport', true);

        sleep(1);
        $this->execute([
            'command'   => 'scheduled-task:run-single',
            'taskName'  => ExportOrdersTask::getTaskName()
        ]);

        return new JsonResponse(null, Response::HTTP_NO_CONTENT);
    }

    /**
     * @throws Exception
     */
    #[Route('/api/june-export-subscribers', name: 'api.extension.export_subscribers', defaults: ['auth_required'=>false], methods: ['GET'])]
    function startSubscriberExport(): Response {
        $this->configService->set('June.config.customerOffset', 0);
        $this->configService->set('June.config.subscriberOffset', 0);
        $this->configService->set('June.config.startSubscriberExport', true);

        sleep(1);
        $this->execute([
            'command'   => 'scheduled-task:run-single',
            'taskName'  => ExportNewsletterSubscriberTask::getTaskName()
        ]);

        return new JsonResponse(null, Response::HTTP_NO_CONTENT);
    }

    private function execute($command) {
        $application = new Application($this->kernel);
        $application->setAutoExit(false);

        if (is_array($command)) {
            $input = new ArrayInput($command);
        } else {
            $input = new ArrayInput([
                'command' => $command
            ]);
        }

        $output = new BufferedOutput();
        try {
            $application->doRun($input, $output);
        } catch (Exception $e) {

        }
    }
}
