<?php declare(strict_types=1);

namespace June\Core\Content\JuneFlowAction\DataResolver;

use June\Core\Content\JuneFlowAction\JuneFlowActionDefinition;
use Shopware\Core\Content\Cms\Aggregate\CmsSlot\CmsSlotEntity;
use Shopware\Core\Content\Cms\DataResolver\CriteriaCollection;
use Shopware\Core\Content\Cms\DataResolver\Element\AbstractCmsElementResolver;
use Shopware\Core\Content\Cms\DataResolver\Element\ElementDataCollection;
use Shopware\Core\Content\Cms\DataResolver\ResolverContext\ResolverContext;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;

class JuneFlowActionDataResolver extends AbstractCmsElementResolver
{
    public function getType(): string
    {
        return 'june-modal';
    }

    public function collect(CmsSlotEntity $slot, ResolverContext $resolverContext): ?CriteriaCollection
    {
        /* get the config from the element */
        $config = $slot->getFieldConfig();

        $criteria = new Criteria();

        $criteria->addFilter(
            new EqualsFilter('id', $config->get('collectToken')->getValue())
        );

        $criteriaCollection = new CriteriaCollection();

        $criteriaCollection->add(
            'june-modal',
            JuneFlowActionDefinition::class,
            $criteria
        );

        return $criteriaCollection;
    }

    public function enrich(CmsSlotEntity $slot, ResolverContext $resolverContext, ElementDataCollection $result): void
    {
        if ($result->get('june_modal')->first() !== null) {
            $slot->setData($result->get('june_modal')->first());
        }
    }
}
